<?php

namespace Stripe;

class SubscriptionTest extends TestCase
{
    const TEST_RESOURCE_ID = 'sub_123';

    public function testIsListable()
    {
        $this->expectsRequest(
            'get',
            '/v1/subscriptions'
        );
        $resources = Subscription::all();
        $this->assertTrue(is_array($resources->data));
        $this->assertSame("Stripe\\Subscription", get_class($resources->data[0]));
    }

    public function testIsRetrievable()
    {
        $this->expectsRequest(
            'get',
            '/v1/subscriptions/' . self::TEST_RESOURCE_ID
        );
        $resource = Subscription::retrieve(self::TEST_RESOURCE_ID);
        $this->assertSame("Stripe\\Subscription", get_class($resource));
    }

    public function testIsCreatable()
    {
        $this->expectsRequest(
            'post',
            '/v1/subscriptions'
        );
        $resource = Subscription::create(array(
            "customer" => "cus_123",
            "plan" => "plan"
        ));
        $this->assertSame("Stripe\\Subscription", get_class($resource));
    }

    public function testIsSaveable()
    {
        $resource = Subscription::retrieve(self::TEST_RESOURCE_ID);
        $resource->metadata["key"] = "value";
        $this->expectsRequest(
            'post',
            '/v1/subscriptions/' . $resource->id
        );
        $resource->save();
        $this->assertSame("Stripe\\Subscription", get_class($resource));
    }

    public function testIsUpdatable()
    {
        $this->expectsRequest(
            'post',
            '/v1/subscriptions/' . self::TEST_RESOURCE_ID
        );
        $resource = Subscription::update(self::TEST_RESOURCE_ID, array(
            "metadata" => array("key" => "value"),
        ));
        $this->assertSame("Stripe\\Subscription", get_class($resource));
    }

    public function testIsCancelable()
    {
        $resource = Subscription::retrieve(self::TEST_RESOURCE_ID);
        $this->expectsRequest(
            'delete',
            '/v1/subscriptions/' . $resource->id
        );
        $resource->cancel();
        $this->assertSame("Stripe\\Subscription", get_class($resource));
    }

    public function testCanDeleteDiscount()
    {
        $resource = Subscription::retrieve(self::TEST_RESOURCE_ID);
        $this->expectsRequest(
            'delete',
            '/v1/subscriptions/' . $resource->id . '/discount'
        );
        $resource->deleteDiscount();
        $this->assertSame("Stripe\\Subscription", get_class($resource));
    }

    public function testSerializeParametersItems()
    {
        $obj = Util\Util::convertToStripeObject(array(
            'object' => 'subscription',
            'items' => Util\Util::convertToStripeObject(array(
                'object' => 'list',
                'data' => array(),
            ), null),
        ), null);
        $obj->items = array(
            array('id' => 'si_foo', 'deleted' => true),
            array('plan' => 'plan_bar'),
        );
        $expected = array(
            'items' => array(
                0 => array('id' => 'si_foo', 'deleted' => true),
                1 => array('plan' => 'plan_bar'),
            ),
        );
        $this->assertSame($expected, $obj->serializeParameters());
    }
}
